package com.fs.course.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.course.domain.FsCourseWatchComment;
import com.fs.course.service.IFsCourseWatchCommentService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 看课评论Controller
 * 
 * @author fs
 * @date 2025-05-26
 */
@RestController
@RequestMapping("/course/courseWatchComment")
public class FsCourseWatchCommentController extends BaseController
{
    @Autowired
    private IFsCourseWatchCommentService fsCourseWatchCommentService;

    /**
     * 查询看课评论列表
     */
    @PreAuthorize("@ss.hasPermi('course:courseWatchComment:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsCourseWatchComment fsCourseWatchComment)
    {
        startPage();
        List<FsCourseWatchComment> list = fsCourseWatchCommentService.selectFsCourseWatchCommentList(fsCourseWatchComment);
        return getDataTable(list);
    }

    /**
     * 导出看课评论列表
     */
    @PreAuthorize("@ss.hasPermi('course:courseWatchComment:export')")
    @Log(title = "看课评论", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsCourseWatchComment fsCourseWatchComment)
    {
        List<FsCourseWatchComment> list = fsCourseWatchCommentService.selectFsCourseWatchCommentList(fsCourseWatchComment);
        ExcelUtil<FsCourseWatchComment> util = new ExcelUtil<FsCourseWatchComment>(FsCourseWatchComment.class);
        return util.exportExcel(list, "看课评论数据");
    }

    /**
     * 获取看课评论详细信息
     */
    @PreAuthorize("@ss.hasPermi('course:courseWatchComment:query')")
    @GetMapping(value = "/{commentId}")
    public AjaxResult getInfo(@PathVariable("commentId") Long commentId)
    {
        return AjaxResult.success(fsCourseWatchCommentService.selectFsCourseWatchCommentByCommentId(commentId));
    }

    /**
     * 新增看课评论
     */
    @PreAuthorize("@ss.hasPermi('course:courseWatchComment:add')")
    @Log(title = "看课评论", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsCourseWatchComment fsCourseWatchComment)
    {
        return toAjax(fsCourseWatchCommentService.insertFsCourseWatchComment(fsCourseWatchComment));
    }

    /**
     * 修改看课评论
     */
    @PreAuthorize("@ss.hasPermi('course:courseWatchComment:edit')")
    @Log(title = "看课评论", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsCourseWatchComment fsCourseWatchComment)
    {
        return toAjax(fsCourseWatchCommentService.updateFsCourseWatchComment(fsCourseWatchComment));
    }

    /**
     * 删除看课评论
     */
    @PreAuthorize("@ss.hasPermi('course:courseWatchComment:remove')")
    @Log(title = "看课评论", businessType = BusinessType.DELETE)
	@DeleteMapping("/{commentIds}")
    public AjaxResult remove(@PathVariable Long[] commentIds)
    {
        return toAjax(fsCourseWatchCommentService.deleteFsCourseWatchCommentByCommentIds(commentIds));
    }
}
